| ruppert_ipd | R Documentation |
OS Curves for IPI 4-5 (red curve) from Figure 2A in Ruppert (2020)
ruppert_ipd
data(ruppert_ipd, package="PwePred")
| Survival.time: | time |
| Status: | 1 for events, 0 for censoring |
We digitize the OS curves for IPI 4-5 (red curve) from Figure 2A in Ruppert (2020), using WebPlotDigitizer (Rohatgi A (2024)). Subsequently, we reconstruct individual subject data (IPD) using the IPDfromKM package (Liu (2021)).
Ruppert AS, Dixon JG, Salles G, Wall A, Cunningham D, Poeschel V, Haioun C, Tilly H, Ghesquieres H, Ziepert M, et al. (2020). "International Prognostic Indices in Diffuse Large B-cell Lymphoma: A Comparison of IPI, R-IPI, and NCCN-IPI." Blood, The Journal of the American Society of Hematology, 135(23), 2041-2048.
Rohatgi A (2024). "Webplotdigitizer: Version 4.7." URL: https://automeris.io/WebPlotDigitizer.
Liu N, Zhou Y, Lee JJ (2021). "IPDfromKM: Reconstruct Individual Patient Data from Published Kaplan-Meier Survival Curves." BMC medical Research Methodology, 21(1), 111.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.